@@ -1,12 +1,12 @@
 from __future__ import annotations
 
-from asyncio.tasks import Task, create_task
+from asyncio.tasks import create_task
 from logging.config import dictConfig
-from typing import Callable, Dict, Tuple, TypeVar, cast, overload
+from typing import Callable, Optional, cast, overload
 
 from . import current_manager, logger
 from .backend import BACKENDS, BaseBackend
-from .types import TManagerParams, TTaskParams, TWorkerParams
+from .types import TManagerParams, TTaskParams, TVWorkerOnErrFn, TVWorkerOnFn, TWorkerParams
 from .worker import Worker
 
 
@@ -23,7 +23,7 @@ class Donald:
 
     _backend: BaseBackend
 
-    def __init__(self, **params):
+    def __init__(self: Donald, **params):
         self._params: TManagerParams = self.defaults
         self.is_started = False
         self.setup(**params)
@@ -33,35 +33,38 @@ class Donald:
     def __repr__(self):
         return f"<Donald {self._params['backend']}>"
 
-    def setup(self, **params):
+    def setup(self: Donald, **params):
         """Setup the manager."""
         if self.is_started:
             raise RuntimeError("Manager is already started")
 
-        self._params: TManagerParams = dict(self._params, **params)
+        self._params = cast(TManagerParams, dict(self._params, **params))
         self._backend = BACKENDS[self._params["backend"]](
             self._params["backend_params"]
         )
 
         logger.setLevel(self._params["log_level"].upper())
         if self._params["log_config"]:
-            dictConfig(self.params["log_config"])
+            dictConfig(self._params["log_config"])
 
     async def start(self):
         """Start the manager."""
-        logger.info("Starting manager")
+        logger.info("Starting tasks manager")
         await self._backend.connect()
         self.is_started = True
+        logger.info("Tasks manager started")
 
     async def stop(self):
-        logger.info("Stopping manager")
+        logger.info("Stopping tasks manager")
         await self._backend.disconnect()
         self.is_started = False
-        logger.info("Manager stopped")
+        logger.info("Tasks manager stopped")
 
-    def create_worker(self, **params):
+    def create_worker(self: Donald, **params):
         """Create a worker."""
-        worker_params: TWorkerParams = dict(self._params["worker_params"], **params)
+        worker_params = cast(
+            TWorkerParams, dict(self._params["worker_params"], **params)
+        )
         return Worker(self._backend, worker_params)
 
     async def __aenter__(self):
@@ -75,15 +78,15 @@ class Donald:
         """Schedule a task to the backend."""
         return self.scheduler.schedule(interval)
 
-    @overload
-    def task(self, **params) -> TWrapper:
-        ...
-
     @overload
     def task(self, fn: Callable) -> TaskWrapper:
         ...
 
-    def task(self, fn: Callable = None, **params):
+    @overload
+    def task(self, **params) -> Callable[[Callable], TaskWrapper]:
+        ...
+
+    def task(self, fn: Optional[Callable] = None, **params):
         """Decorator to wrap a function into a Task object."""
 
         def wrapper(fn: Callable) -> TaskWrapper:
@@ -94,24 +97,24 @@ class Donald:
 
         return wrapper(fn)
 
-    def submit(self, run: TaskRun) -> Task:
+    def submit(self, run: TaskRun):
         """Submit a task to the backend."""
         if not self.is_started:
             raise RuntimeError("Manager is not started")
 
         return create_task(self._backend.submit(run.data))
 
-    def on_start(self, fn: Callable):
+    def on_start(self, fn: TVWorkerOnFn) -> TVWorkerOnFn:
         """Register a function to be called on worker start."""
         self._params["worker_params"]["on_start"] = fn
         return fn
 
-    def on_stop(self, fn: Callable):
+    def on_stop(self, fn: TVWorkerOnFn) -> TVWorkerOnFn:
         """Register a function to be called on worker stop."""
         self._params["worker_params"]["on_stop"] = fn
         return fn
 
-    def on_error(self, fn: Callable):
+    def on_error(self, fn: TVWorkerOnErrFn) -> TVWorkerOnErrFn:
         """Register a function to be called on worker error."""
         self._params["worker_params"]["on_error"] = fn
         return fn
@@ -119,5 +122,3 @@ class Donald:
 
 from .scheduler import Scheduler, TInterval
 from .tasks import TaskRun, TaskWrapper
-
-TWrapper = TypeVar("TWrapper", bound=Callable[[Callable], TaskWrapper])
