@@ -23,7 +23,7 @@ class Scheduler:
         self._finished = None
 
     def start(self):
-        logger.info("Starting scheduler")
+        logger.info("Starting task scheduler")
         self._finished = Event()
         for scheduler in self._schedule:
             self._tasks.append(create_task(scheduler()))
@@ -33,7 +33,8 @@ class Scheduler:
             task.cancel()
 
         await self.join()
-        self._finished.set()
+        if self._finished is not None:
+            self._finished.set()
 
     def wait(self):
         if self._finished is None:
